
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'FlutterBaseBanner.dart';
import 'FlutterBidmadCommon.dart';

class BidmadBannerWidget extends StatefulWidget {
  final BidmadBannerWidgetCreatedCallback onBidmadBannerWidgetCreated;

  const BidmadBannerWidget({
    Key? key,
    required this.onBidmadBannerWidgetCreated,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => BidmadBannerWidgetState();
}

typedef BidmadBannerWidgetCreatedCallback = void Function(FlutterBaseBanner controller);

class BidmadBannerWidgetState extends State<BidmadBannerWidget> {
  FlutterBidmadCommon common = FlutterBidmadCommon();
  String defaultChannelNm = "com.bidmad.sdk.banner/Widget_";
  late FlutterBaseBanner banner;

  @override
  void dispose() {
    print("BidmadBannerWidget dispose");
    if(banner != null){
      banner.removeBanner();
    }
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    // This is used in the platform side to register the view.
    common.initBannerWidget();

    final String viewType = 'BidmadBannerWidget';
    // Pass parameters to the platform side.
    final Map<String, dynamic> creationParams = <String, dynamic>{};

    if(defaultTargetPlatform == TargetPlatform.android) {
      return AndroidView(
        viewType: viewType,
        creationParams: creationParams,
        onPlatformViewCreated: _onPlatformViewCreated,
        creationParamsCodec: const StandardMessageCodec(),
      );
    } else if(defaultTargetPlatform == TargetPlatform.iOS) {
      return UiKitView(
        viewType: viewType,
        creationParams: creationParams,
        onPlatformViewCreated: _onPlatformViewCreated,
        creationParamsCodec: const StandardMessageCodec(),
      );
    } else{
      throw Exception("Not Support Platform");
    }
  }
  void _onPlatformViewCreated(int id) {

    print("_onPlatformViewCreated : " + id.toString());
    if (widget.onBidmadBannerWidgetCreated == null) {
      return;
    }
    banner = FlutterBaseBanner(channelName: defaultChannelNm+id.toString());
    widget.onBidmadBannerWidgetCreated(banner);
  }
}